@@ -26,12 +26,10 @@
 K_PLUGIN_FACTORY_WITH_JSON(SvgPartFactory, "svgpart.json", registerPlugin<SvgPart>();)
 
 SvgPart::SvgPart(QWidget *parentWidget, QObject *parent, const KPluginMetaData &metaData, const QVariantList &)
-    : KParts::ReadOnlyPart(parent)
+    : KParts::ReadOnlyPart(parent, metaData)
     , mItem(nullptr)
     , m_browserExtension(new SvgBrowserExtension(this))
 {
-    setMetaData(metaData);
-
     mRenderer = new QSvgRenderer(this);
     mScene = new QGraphicsScene(this);
     mView = new SvgView(mScene, parentWidget);
